from alibabacloud_dysmsapi20170525.models import SendSmsRequest
from alibabacloud_dysmsapi20170525.client import Client
from alibabacloud_tea_openapi.models import Config
import json


class SMS:
    client: Client

    def __init__(self,
                 access_key_id: str,
                 access_key_secret: str,
                 region_id: str = 'dysmsapi.aliyuncs.com') -> None:
        config = Config(access_key_id=access_key_id,
                        access_key_secret=access_key_secret,
                        region_id=region_id)
        self.client = Client(config=config)

    def send(self, phone_num, sign_name: str, template_code: str,
             params: dict):
        req = SendSmsRequest(phone_numbers=str(phone_num),
                             sign_name=sign_name,
                             template_code=template_code,
                             template_param=json.dumps(params))
        try:
            res = self.client.send_sms(request=req)
            data = res.to_map()
            if data['statusCode'] >= 200 and data['statusCode'] < 300 and data[
                    'body']['Code'] == 'OK':
                return None
            return data['body']['Message']
        except Exception as e:
            return f'{e}'



from setuptools import setup, find_packages

setup(
    name="notice_py",
    version="0.1.7",
    author="zefzhou44",
    author_email="zefzhou44@gmail.com",
    description="lark/sms/voice notice package",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/zefzhou/notice_py",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8.0",
    install_requires=[
        "requests", "alibabacloud_dysmsapi20170525", "tenacity",
        "python-dotenv"
    ],
)



import requests
from tenacity import retry, stop_after_attempt, wait_fixed
import json

voice_url = "http://api.vm.ihuyi.com/webservice/voice.php?method=Submit"
voice_headers = {
    "Content-type": "application/x-www-form-urlencoded",
    "Accept": "text/plain"
}


class Voice:

    def __init__(self, account: str, password: str) -> None:
        self.account = account
        self.password = password

    def send(self, mobile_num, content: str, format: str = 'json'):
        try:
            self.send_(mobile_num=mobile_num, content=content, format=format)
        except Exception as e:
            return f'{e}'
        finally:
            return None

    @retry(stop=stop_after_attempt(3), wait=wait_fixed(2))
    def send_(self, mobile_num, content: str, format: str = 'json'):
        data = {
            'account': self.account,
            'password': self.password,
            'mobile': str(mobile_num),
            'content': content,
            'format': format,
        }

        response = requests.post(url=voice_url,
                                 headers=voice_headers,
                                 data=data)
        resp_data = json.loads(response.text)
        if resp_data['code'] != 2:
            raise ValueError(f'{resp_data["msg"]}')



import requests
from tenacity import retry, stop_after_attempt, wait_fixed
import json


class Lark:
    webhook_url: str

    def __init__(self, webhook_url: str) -> None:
        self.webhook_url = webhook_url

    def send(self, msg: str):
        try:
            self.send_(msg=msg)
        except Exception as e:
            return f'{e}'
        finally:
            return None

    @retry(stop=stop_after_attempt(3), wait=wait_fixed(1))
    def send_(self, msg: str):
        json_data = {
            'msg_type': 'text',
            'content': {
                'text': msg,
            }
        }
        resp = requests.post(url=self.webhook_url, json=json_data)
        resp_data = json.loads(resp.text)
        if resp.status_code >= 200 and resp.status_code < 300:
            if resp_data['StatusCode'] != 0:
                raise ValueError(f'{resp_data["StatusMessage"]}')
        else:
            raise ValueError(f'status_code : {resp.status_code}')



from .lark import Lark
from .sms import SMS
from .voice import Voice
import json
from dotenv import dotenv_values


class Notice:
    lark_: Lark
    sms_: SMS
    voice_: Voice
    mobile_num: str
    voice_content: str

    def __init__(self, env_file_path: str):
        dict = dotenv_values(dotenv_path=env_file_path)
        print(f'notice env loaded. {dict}')
        self.mobile_num = dict['mobile_num']
        self.voice_content = dict['voice_content']

        if 'bot_webhook_url' in dict:
            bot_webhook_url = dict['bot_webhook_url']
            self.lark_ = Lark(webhook_url=bot_webhook_url)

        if 'sms_access_key_id' in dict and 'sms_access_key_secret' in dict:
            sms_access_key_id = dict['sms_access_key_id']
            sms_access_key_secret = dict['sms_access_key_secret']
            self.sms_ = SMS(access_key_id=sms_access_key_id,
                            access_key_secret=sms_access_key_secret)

        if 'voice_account' in dict and 'voice_password' in dict:
            voice_account = dict['voice_account']
            voice_password = dict['voice_password']
            self.voice_ = Voice(account=voice_account, password=voice_password)

    def send_lark(self, msg: str):
        return self.lark_.send(msg=msg)

    def send_lark_and_voice(self, msg: str, voice_first: bool = True):
        msg = '【电话消息】 ' + msg
        if voice_first:
            voice_resp = self.voice_.send(mobile_num=self.mobile_num,
                                          content=self.voice_content)
            lark_resp = self.lark_.send(msg=msg)
        else:
            lark_resp = self.lark_.send(msg=msg)
            voice_resp = self.voice_.send(mobile_num=self.mobile_num,
                                          content=self.voice_content)
        resp = {}
        if lark_resp is not None:
            resp['lark_resp'] = lark_resp
        if voice_resp is not None:
            resp['voice_resp'] = voice_resp
        if len(resp) > 0:
            return json.dumps(resp)
        return None


if __name__ == '__main__':
    notice_ = Notice(env_file_path='/xxx/.env')
    notice_.send_lark_and_voice(msg='just a test', voice_first=True)
